@@ -6,10 +6,6 @@ from .processors import (
     JsonLineProcessor,
     MsgpackProcessor,
 )
-from .serializers import (
-    StringSerializer,
-    JsonSerializer,
-    MsgpackSerializer,
-)
+from .serializers import StringSerializer, JsonSerializer, MsgpackSerializer
 from .checkpointers import MemoryCheckPointer, RedisCheckPointer
 from .aggregators import SimpleAggregator, NewlineAggregator, NetstringAggregator
