@@ -1,6 +1,7 @@
 import asyncio
 import aiobotocore
 import logging
+from contextlib import AsyncExitStack
 from async_timeout import timeout
 from asyncio import CancelledError
 from botocore.exceptions import ClientError
@@ -20,6 +21,7 @@ class Base:
         self.endpoint_url = endpoint_url
         self.region_name = region_name
 
+        self.exit_stack = AsyncExitStack()
         self.client = None
         self.shards = None
 
@@ -33,26 +35,27 @@ class Base:
             )
         )
 
-        session = aiobotocore.get_session()
+        session = aiobotocore.session.AioSession()
 
         # Note: max_attempts = 0
         # Boto RetryHandler only handles these errors:
         #  GENERAL_CONNECTION_ERROR => ConnectionError, ConnectionClosedError, ReadTimeoutError, EndpointConnectionError
         # Still have to handle ClientError anyway~
 
-        self.client = session.create_client(
+        self.client = await self.exit_stack.enter_async_context(session.create_client(
             "kinesis",
             endpoint_url=self.endpoint_url,
             region_name=self.region_name,
             config=Config(
                 connect_timeout=5, read_timeout=90, retries={"max_attempts": 0}
             ),
-        )
+        ))
 
         return self
 
     async def __aexit__(self, exc_type, exc, tb):
         await self.close()
+        await self.exit_stack.__aexit__(exc_type, exc, tb)
 
     async def get_stream_description(self):
 
@@ -66,6 +69,7 @@ class Base:
                 raise exceptions.StreamDoesNotExist(
                     "Stream '{}' does not exist".format(self.stream_name)
                 ) from None
+            raise
 
     async def start(self, skip_describe_stream=False):
 
